==> jquery-maskmoney-3.0.1.tgz: jquery-maskmoney/README.md <==
# Installation
> `npm install --save @types/jquery-maskmoney`

# Summary
This package contains type definitions for jQuery maskMoney (https://github.com/plentz/jquery-maskmoney).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-maskmoney.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-maskmoney/index.d.ts)
````ts
// Type definitions for jQuery maskMoney 3.0
// Project: https://github.com/plentz/jquery-maskmoney
// Definitions by: Anderson Friaça <https://github.com/AndersonFriaca>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery" />

declare namespace jQueryMaskMoney {
    interface Options {
        /**
         * The prefix to be displayed before the value entered
         */
        prefix?: string | undefined;

        /**
         * The prefix to be displayed after the value entered
         */
        suffix?: string | undefined;

        /**
         * Set if the prefix and suffix will stay in the field's value after the user exits the field
         */
        affixesStay?: boolean | undefined;

        /**
         * The thousands separator
         */
        thousands?: string | undefined;

        /**
         * The decimal separator
         */
        decimal?: string | undefined;

        /**
         * How many decimal places are allowed
         */
        precision?: number | undefined;

        /**
         * Setting to prevent users from inputing zero
         */
        allowZero?: boolean | undefined;

        /**
         * Setting to prevent negative values
         */
        allowNegative?: boolean | undefined;
    }
}
interface JQuery {
    /**
     * Apply mask to input, can be pass default value to it
     */
    maskMoney(methodName: 'mask', defaultValue?: number): JQuery;

    /**
     * Returns a float value from input field masked
     */
    maskMoney(method?: 'unmasked'): number[];

    /**
     * Apply mask to input when the argument are options
     * Remove maskMoney from an element when the argument is "destroy"
     */
    maskMoney(methodOrOption?: 'destroy' | jQueryMaskMoney.Options): JQuery;
}

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 16:22:28 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Anderson Friaça](https://github.com/AndersonFriaca).

==> jquery-maskmoney-3.0.2.tgz: jquery-maskmoney/README.md <==
# Installation
> `npm install --save @types/jquery-maskmoney`

# Summary
This package contains type definitions for jQuery maskMoney (https://github.com/plentz/jquery-maskmoney).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-maskmoney.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-maskmoney/index.d.ts)
````ts
// Type definitions for jQuery maskMoney 3.0
// Project: https://github.com/plentz/jquery-maskmoney
// Definitions by: Anderson Friaça <https://github.com/AndersonFriaca>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery" />

declare namespace jQueryMaskMoney {
    interface Options {
        /**
         * The prefix to be displayed before the value entered
         */
        prefix?: string | undefined;

        /**
         * The prefix to be displayed after the value entered
         */
        suffix?: string | undefined;

        /**
         * Set if the prefix and suffix will stay in the field's value after the user exits the field
         */
        affixesStay?: boolean | undefined;

        /**
         * The thousands separator
         */
        thousands?: string | undefined;

        /**
         * The decimal separator
         */
        decimal?: string | undefined;

        /**
         * How many decimal places are allowed
         */
        precision?: number | undefined;

        /**
         * Setting to prevent users from inputing zero
         */
        allowZero?: boolean | undefined;

        /**
         * Setting to prevent negative values
         */
        allowNegative?: boolean | undefined;
    }
}
interface JQuery {
    /**
     * Apply mask to input, can be pass default value to it
     */
    maskMoney(methodName: "mask", defaultValue?: number): JQuery;

    /**
     * Returns a float value from input field masked
     */
    maskMoney(method?: "unmasked"): number[];

    /**
     * Apply mask to input when the argument are options
     * Remove maskMoney from an element when the argument is "destroy"
     */
    maskMoney(methodOrOption?: "destroy" | jQueryMaskMoney.Options): JQuery;
}

````

### Additional Details
 * Last updated: Fri, 15 Sep 2023 20:36:37 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Anderson Friaça](https://github.com/AndersonFriaca).
